from .jdoodle import Compiler

############
# METADATA #
############

__version__ = "v1.0.0"
__title__ = "pydoodle"
__license__ = "MIT"
__author__ = "Prince2347X"
__github__ = "https://github.com/Prince2347X/pydoodle"
